=========
CRNT4SBML
=========


.. image:: https://img.shields.io/pypi/v/crnt4sbml.svg
        :target: https://pypi.python.org/pypi/crnt4sbml
..
    .. image:: https://img.shields.io/travis/PNNL-Comp-Mass-Spec/CRNT4SBML.svg
        :target: https://travis-ci.org/PNNL-Comp-Mass-Spec/CRNT4SBML

.. image:: https://readthedocs.org/projects/crnt4sbml/badge/?version=latest
        :target: https://crnt4sbml.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

CRNT4SBML is a cross-platform and easily installable Python based package. CRNT4SBML is concentrated on providing a
simple workflow for the testing of core CRNT methods directed at detecting bistability in cell signaling pathways
endowed with mass action kinetics.

* Free software: Apache Software License 2.0
* Documentation: https://crnt4sbml.readthedocs.io.


Features
--------

* Routine for testing of the Deficiency Zero and One Theorems.
* Routine for running the mass conservation approach.
* Routine for running the semi-diffusive approach.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
